==> phpicalendar-2.1p0.tgz: phpicalendar/languages/italian.inc.php <==
<?php

// Italian language include
// For version 2.0 PHP iCalendar
//
// First translation by Luca Cacciagrano (clooka@clac.it)
// Updated translation by Daniele Nicolucci (jollino@discussioni.org)
// v.2 updated translation by Mattia Grosso (testone at inwind dot it)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Giorno';
$lang['l_week'] 			= 'Settimana';
$lang['l_month'] 			= 'Mese';
$lang['l_year'] 			= 'Anno';
$lang['l_calendar'] 		= 'Calendario';
$lang['l_next_day'] 		= 'Giorno Successivo';
$lang['l_next_month'] 		= 'Mese Successivo';
$lang['l_next_week'] 		= 'Settimana Successiva';
$lang['l_next_year'] 		= 'Anno Successivo';
$lang['l_last_day'] 		= 'GIorno Precedente';
$lang['l_last_month'] 		= 'Mese Precedente';
$lang['l_last_week'] 		= 'Settimana Precedente';
$lang['l_last_year'] 		= 'Anno Precedente';
$lang['l_subscribe'] 		= 'Sottoscrivi';
$lang['l_download'] 		= 'Scarica';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= 'Evento';
$lang['l_event_start'] 		= 'Inizio';
$lang['l_event_end'] 		= 'Fine';
$lang['l_this_months'] 		= 'Eventi di questo mese';
$lang['l_date'] 			= 'Data';
$lang['l_summary'] 			= 'Sommario';
$lang['l_all_day'] 			= 'Eventi giornalieri';
$lang['l_notes'] 			= 'Note';
$lang['l_this_years'] 		= 'Eventi di quest\'anno';
$lang['l_today'] 			= 'Oggi';
$lang['l_this_week'] 		= 'Questa Settimana';
$lang['l_this_month'] 		= 'Questo Mese';
$lang['l_jump'] 			= 'Vai a';
$lang['l_tomorrows'] 		= 'Eventi di domani';
$lang['l_goday'] 			= 'Vai a Oggi';
$lang['l_goweek'] 			= 'Vai a Questa Settimana';
$lang['l_gomonth'] 			= 'Vai a Questo Mese';
$lang['l_goyear'] 			= 'Vai a Questo Anno';
$lang['l_search'] 			= 'Cerca'; // the verb
$lang['l_results'] 			= 'Risultati Ricerca';
$lang['l_query'] 			= 'Chiave di ricerca'; // will be followed by the search query
$lang['l_no_results'] 		= 'Nessun evento trovato';
$lang['l_goprint'] 			= 'Versione Stampabile';
$lang['l_time'] 			= 'Ora';
$lang['l_summary'] 			= 'Sommario';
$lang['l_description'] 		= 'Descrizione';
$lang['l_this_site_is']		= 'Questo sito &egrave;';
$lang['l_no_events_day']	= 'Nessun evento per oggi.';
$lang['l_no_events_week']	= 'Nessun evento per questa settimana.';
$lang['l_no_events_month']	= 'Nessun evento per questo mese.';
$lang['l_rss_day_date']		= 'G:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_language']		= 'it-it';
$lang['l_search_took']		= 'La ricerca ha richiesto %s secondi';
$lang['l_recurring_event']	= 'Evento ricorrente';
$lang['l_exception']		= 'Eccezione';
$lang['l_no_query']			= 'Nessuna chiave di ricerca specificata';
$lang['l_preferences']		= 'Preferenze';
$lang['l_printer']			= 'Stampante';
$lang['l_select_lang']		= 'Seleziona la lingua predefinita';
$lang['l_select_cal']		= 'Seleziona il calendario predefinito';
$lang['l_select_view']		= 'Seleziona la vista predefinita';
$lang['l_select_time']		= 'Seleziona l\'ora di inizio predefinita';
$lang['l_select_day']		= 'Seleziona il giorno di inizio settimana predefinito';
$lang['l_select_style']		= 'Seleziona lo stile predefinito';
$lang['l_set_prefs']		= 'Imposta le preferenze';
$lang['l_completed_date']	= 'Completato il';
$lang['l_completed']		= 'Completato';
$lang['l_created']			= 'Creato';
$lang['l_due']				= 'Fatto';
$lang['l_priority']			= 'Priorit&agrave;';
$lang['l_priority_high']	= 'Alta';
$lang['l_priority_low']		= 'Bassa';
$lang['l_priority_medium']	= 'Media';
$lang['l_priority_none']	= 'Nessuna';
$lang['l_status']			= 'Stato';
$lang['l_todo']				= 'Attivit&agrave;';
$lang['l_unfinished']		= 'Non terminato';
$lang['l_prefs_set'] 		= 'Le tue preferenze sono state registrate.';
$lang['l_prefs_unset'] 		= 'Preferenze annullate. Le modifiche avranno effetto al caricamento della prossima pagina.';
$lang['l_unset_prefs'] 		= 'Ripristina le impostazioni iniziali';
$lang['l_organizer']		= 'Organizzatore';
$lang['l_attendee']			= 'Invitato';
$lang['l_location']			= 'Luogo';
$lang['l_admin_header']		= 'Amministrazione PHP iCalendar';
$lang['l_username']			= 'Nome utente';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Entra';
$lang['l_invalid_login']	= 'Nome utente o password errata.';
$lang['l_addupdate_cal']	= 'Aggiungi o Aggiorna un Calendario';
$lang['l_addupdate_desc']	= 'Aggiungi un calendario caricando un nuovo file. L\'aggiornamento si effettua caricando un calendario con lo stesso nome.';
$lang['l_delete_cal']		= 'Elimina un Calendario';
$lang['l_logout']			= 'Esci';
$lang['l_cal_file']			= 'File Calendario';
$lang['l_php_error']		= 'Errore PHP';
$upload_error_gen_lang		= 'Si &egrave; verificato un problema durante il caricamento.';
$upload_error_lang[0]		= 'Si &egrave; verificato un problema durante il caricamento.';
$upload_error_lang[1]		= 'Il documento che stai cercando di caricare &egrave; troppo grande.';
$upload_error_lang[2]		= 'Il documento che stai cercando di caricare &egrave; troppo grande.';
$upload_error_lang[3]		= 'Il documento che stai cercando di caricare &egrave; stato trasferito solo in parte.';
$upload_error_lang[4]		= 'Devi selezionare un file da caricare.';
$lang['l_upload_error_type'] = 'Solo i documenti .ics possono essere caricati.';
$lang['l_copy_error']			= 'Errore durante la copia del documento';
$lang['l_delete_error']			= 'Errore durante l\'eliminazione del documento';
$lang['l_delete_success']		= '&egrave; stato eliminato correttamente.';
$lang['l_action_success']		= 'La tua azione &egrave; andata a buon fine.';
$lang['l_submit']				= 'Conferma';
$lang['l_delete']				= 'Cancella';
$all_cal_comb_lang			= 'Tutti assieme';

// New for 2.0
$lang['l_legend']			= 'Legenda';
$lang['l_admin_subhead']	= 'Gestisci i tuoi calendari da questa pagina';
$lang['l_prefs_subhead']	= 'Imposta un cookie per la visita a questo sito';
$lang['l_rss_info']			= 'Informazione RSS';
$lang['l_rss_subhead']		= 'I feed RSS di base sono disponibili per ogni calendario';
$lang['l_rss_notenabled']	= 'RSS non &egrave; abilitato per questo sito';

// - navigation
$lang['l_back'] 		= 'Indietro';
$lang['l_next'] 		= 'Avanti';
$lang['l_prev'] 		= 'Precedente';
$lang['l_day_view'] 	= 'Vista per Giorno';
$lang['l_week_view'] 	= 'Vista per Settimana';
$lang['l_month_view'] 	= 'Vista per Mese';
$lang['l_year_view'] 	= 'Vista per Anno';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('anno','anni');		// for these, put singular
$format_recur_lang['monthly']		= array('mese','mesi');		// and plural forms
$format_recur_lang['weekly']		= array('settimana','settimane');		// these will be %freq%
$format_recur_lang['daily']			= array('giorno','giorni');			// in the replacement below
$format_recur_lang['hourly']		= array('ora','ore');
$format_recur_lang['minutely']		= array('miniuto','minuti');
$format_recur_lang['secondly']		= array('secondo','secondi');

$format_recur_lang['start']			= 'Ogni %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'fino a: %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'per %int% volte';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Nei mesi: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'In data: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Nei giorni: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Domenica','Luned&igrave;','Marted&igrave;','Mercoled&igrave;','Gioved&igrave;','Venerd&igrave;','Sabato');
$daysofweekshort_lang		= array ('Dom','Lun','Mar','Mer','Gio','Ven','Sab');
$daysofweekreallyshort_lang	= array ('D','L','M','M','G','V','S');
$monthsofyear_lang			= array ('Gennaio','Febbraio','Marzo','Aprile','Maggio','Giugno','Luglio','Agosto','Settembre','Ottobre','Novembre','Dicembre');
$monthsofyearshort_lang		= array ('Gen','Feb','Mar','Apr','Mag','Giu','Lul','Ago','Set','Ott','Nov','Dic');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'G:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a, %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e %B';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Errore!';
$lang['l_error_window'] 		= 'Si &egrave; verificato un errore!';
$lang['l_error_calendar'] 		= 'Questo errore si &egrave; verificato durante l\'elaborazione del Calendario "%s".';
$lang['l_error_path'] 			= 'Impossibile aprire il percorso: "%s"';
$lang['l_error_back'] 			= 'Usa il tasto "Indietro" per tornare alla pagina precedente.';
$lang['l_error_remotecal'] 		= 'Questa server blocca i calendari remoti che non sono stati approvati.';
$lang['l_error_restrictedcal'] 	= 'Hai cercato di consultare un calendario protetto su questo server.';
$lang['l_error_invalidcal'] 	= 'Documento calendario non corretto. Prova un altro calendario.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>

==> phpicalendar-2.31.tgz: phpicalendar/languages/italian.inc.php <==
<?php

// Italian language include
// For version 2.0 PHP iCalendar
//
// First translation by Luca Cacciagrano (clooka@clac.it)
// Updated translation by Daniele Nicolucci (jollino@discussioni.org)
// v.2 updated translation by Mattia Grosso (testone at inwind dot it)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Giorno';
$lang['l_week'] 			= 'Settimana';
$lang['l_month'] 			= 'Mese';
$lang['l_year'] 			= 'Anno';
$lang['l_calendar'] 		= 'Calendario';
$lang['l_next_day'] 		= 'Giorno Successivo';
$lang['l_next_month'] 		= 'Mese Successivo';
$lang['l_next_week'] 		= 'Settimana Successiva';
$lang['l_next_year'] 		= 'Anno Successivo';
$lang['l_last_day'] 		= 'GIorno Precedente';
$lang['l_last_month'] 		= 'Mese Precedente';
$lang['l_last_week'] 		= 'Settimana Precedente';
$lang['l_last_year'] 		= 'Anno Precedente';
$lang['l_subscribe'] 		= 'Sottoscrivi';
$lang['l_download'] 		= 'Scarica';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= 'Evento';
$lang['l_event_start'] 		= 'Inizio';
$lang['l_event_end'] 		= 'Fine';
$lang['l_this_months'] 		= 'Eventi di questo mese';
$lang['l_date'] 			= 'Data';
$lang['l_summary'] 			= 'Sommario';
$lang['l_all_day'] 			= 'Eventi giornalieri';
$lang['l_notes'] 			= 'Note';
$lang['l_this_years'] 		= 'Eventi di quest\'anno';
$lang['l_today'] 			= 'Oggi';
$lang['l_this_week'] 		= 'Questa Settimana';
$lang['l_this_month'] 		= 'Questo Mese';
$lang['l_jump'] 			= 'Vai a';
$lang['l_tomorrows'] 		= 'Eventi di domani';
$lang['l_goday'] 			= 'Vai a Oggi';
$lang['l_goweek'] 			= 'Vai a Questa Settimana';
$lang['l_gomonth'] 			= 'Vai a Questo Mese';
$lang['l_goyear'] 			= 'Vai a Questo Anno';
$lang['l_search'] 			= 'Cerca'; // the verb
$lang['l_results'] 			= 'Risultati Ricerca';
$lang['l_pick_multiple'] 	= 'Selezione multipla';
$lang['l_query'] 			= 'Chiave di ricerca'; // will be followed by the search query
$lang['l_no_results'] 		= 'Nessun evento trovato';
$lang['l_goprint'] 			= 'Versione Stampabile';
$lang['l_time'] 			= 'Ora';
$lang['l_summary'] 			= 'Sommario';
$lang['l_description'] 		= 'Descrizione';
$lang['l_this_site_is']		= 'Questo sito &egrave;';
$lang['l_no_events_day']	= 'Nessun evento per oggi.';
$lang['l_no_events_week']	= 'Nessun evento per questa settimana.';
$lang['l_no_events_month']	= 'Nessun evento per questo mese.';
$lang['l_rss_day_date']		= 'G:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_language']		= 'it-it';
$lang['l_search_took']		= 'La ricerca ha richiesto %s secondi';
$lang['l_recurring_event']	= 'Evento ricorrente';
$lang['l_exception']		= 'Eccezione';
$lang['l_no_query']			= 'Nessuna chiave di ricerca specificata';
$lang['l_preferences']		= 'Preferenze';
$lang['l_printer']			= 'Stampante';
$lang['l_select_lang']		= 'Seleziona la lingua predefinita';
$lang['l_select_cal']		= 'Seleziona il calendario predefinito';
$lang['l_select_view']		= 'Seleziona la vista predefinita';
$lang['l_select_time']		= 'Seleziona l\'ora di inizio predefinita';
$lang['l_select_day']		= 'Seleziona il giorno di inizio settimana predefinito';
$lang['l_select_style']		= 'Seleziona lo stile predefinito';
$lang['l_set_prefs']		= 'Imposta le preferenze';
$lang['l_completed_date']	= 'Completato il';
$lang['l_completed']		= 'Completato';
$lang['l_created']			= 'Creato';
$lang['l_due']				= 'Fatto';
$lang['l_priority']			= 'Priorit&agrave;';
$lang['l_priority_high']	= 'Alta';
$lang['l_priority_low']		= 'Bassa';
$lang['l_priority_medium']	= 'Media';
$lang['l_priority_none']	= 'Nessuna';
$lang['l_status']			= 'Stato';
$lang['l_status_confirmed'] = 'Confermato' ; 
$lang['l_status_cancelled'] = 'Annullato'; 
$lang['l_status_tentative'] = 'Sperimentale'; 
$lang['l_todo']				= 'Attivit&agrave;';
$lang['l_unfinished']		= 'Non terminato';
$lang['l_prefs_set'] 		= 'Le tue preferenze sono state registrate.';
$lang['l_prefs_unset'] 		= 'Preferenze annullate. Le modifiche avranno effetto al caricamento della prossima pagina.';
$lang['l_unset_prefs'] 		= 'Ripristina le impostazioni iniziali';
$lang['l_organizer']		= 'Organizzatore';
$lang['l_attendee']			= 'Invitato';
$lang['l_location']			= 'Luogo';
$lang['l_admin_header']		= 'Amministrazione PHP iCalendar';
$lang['l_username']			= 'Nome utente';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Entra';
$lang['l_invalid_login']	= 'Nome utente o password errata.';
$lang['l_addupdate_cal']	= 'Aggiungi o Aggiorna un Calendario';
$lang['l_addupdate_desc']	= 'Aggiungi un calendario caricando un nuovo file. L\'aggiornamento si effettua caricando un calendario con lo stesso nome.';
$lang['l_delete_cal']		= 'Elimina un Calendario';
$lang['l_logout']			= 'Esci';
$lang['l_cal_file']			= 'File Calendario';
$lang['l_php_error']		= 'Errore PHP';
$upload_error_gen_lang		= 'Si &egrave; verificato un problema durante il caricamento.';
$upload_error_lang[0]		= 'Si &egrave; verificato un problema durante il caricamento.';
$upload_error_lang[1]		= 'Il documento che stai cercando di caricare &egrave; troppo grande.';
$upload_error_lang[2]		= 'Il documento che stai cercando di caricare &egrave; troppo grande.';
$upload_error_lang[3]		= 'Il documento che stai cercando di caricare &egrave; stato trasferito solo in parte.';
$upload_error_lang[4]		= 'Devi selezionare un file da caricare.';
$lang['l_upload_error_type'] = 'Solo i documenti .ics possono essere caricati.';
$lang['l_copy_error']			= 'Errore durante la copia del documento';
$lang['l_delete_error']			= 'Errore durante l\'eliminazione del documento';
$lang['l_delete_success']		= '&egrave; stato eliminato correttamente.';
$lang['l_action_success']		= 'La tua azione &egrave; andata a buon fine.';
$lang['l_submit']				= 'Conferma';
$lang['l_delete']				= 'Cancella';
$all_cal_comb_lang			= 'Tutti assieme';

// New for 2.0
$lang['l_legend']			= 'Legenda';
$lang['l_admin_subhead']	= 'Gestisci i tuoi calendari da questa pagina';
$lang['l_prefs_subhead']	= 'Imposta un cookie per la visita a questo sito';
$lang['l_rss_info']			= 'Informazione RSS';
$lang['l_rss_subhead']		= 'I feed RSS di base sono disponibili per ogni calendario';
$lang['l_rss_notenabled']	= 'RSS non &egrave; abilitato per questo sito';

// - navigation
$lang['l_back'] 		= 'Indietro';
$lang['l_next'] 		= 'Avanti';
$lang['l_prev'] 		= 'Precedente';
$lang['l_day_view'] 	= 'Vista per Giorno';
$lang['l_week_view'] 	= 'Vista per Settimana';
$lang['l_month_view'] 	= 'Vista per Mese';
$lang['l_year_view'] 	= 'Vista per Anno';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('anno','anni');		// for these, put singular
$format_recur_lang['monthly']		= array('mese','mesi');		// and plural forms
$format_recur_lang['weekly']		= array('settimana','settimane');		// these will be %freq%
$format_recur_lang['daily']			= array('giorno','giorni');			// in the replacement below
$format_recur_lang['hourly']		= array('ora','ore');
$format_recur_lang['minutely']		= array('miniuto','minuti');
$format_recur_lang['secondly']		= array('secondo','secondi');

$format_recur_lang['start']			= 'Ogni %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'fino a: %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'per %int% volte';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Nei mesi: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'In data: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Nei giorni: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Domenica','Luned&igrave;','Marted&igrave;','Mercoled&igrave;','Gioved&igrave;','Venerd&igrave;','Sabato');
$daysofweekshort_lang		= array ('Dom','Lun','Mar','Mer','Gio','Ven','Sab');
$daysofweekreallyshort_lang	= array ('D','L','M','M','G','V','S');
$monthsofyear_lang			= array ('Gennaio','Febbraio','Marzo','Aprile','Maggio','Giugno','Luglio','Agosto','Settembre','Ottobre','Novembre','Dicembre');
$monthsofyearshort_lang		= array ('Gen','Feb','Mar','Apr','Mag','Giu','Lul','Ago','Set','Ott','Nov','Dic');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'G:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a, %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Errore!';
$lang['l_error_window'] 		= 'Si &egrave; verificato un errore!';
$lang['l_error_calendar'] 		= 'Questo errore si &egrave; verificato durante l\'elaborazione del Calendario "%s".';
$lang['l_error_path'] 			= 'Impossibile aprire il percorso: "%s"';
$lang['l_error_back'] 			= 'Usa il tasto "Indietro" per tornare alla pagina precedente.';
$lang['l_error_remotecal'] 		= 'Questa server blocca i calendari remoti che non sono stati approvati.';
$lang['l_error_restrictedcal'] 	= 'Hai cercato di consultare un calendario protetto su questo server.';
$lang['l_error_invalidcal'] 	= 'Documento calendario non corretto. Prova un altro calendario.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>
